@@ -1,18 +1,28 @@
+from sqlalchemy_declarative_extensions import dialects
 from sqlalchemy_declarative_extensions.alembic import register_alembic_events
-from sqlalchemy_declarative_extensions.api import declarative_database, declare_database
 from sqlalchemy_declarative_extensions.grant import Grants
-from sqlalchemy_declarative_extensions.role import PGRole, Role, Roles
+from sqlalchemy_declarative_extensions.role import Role
+from sqlalchemy_declarative_extensions.role.base import Roles
 from sqlalchemy_declarative_extensions.row import Row, Rows
 from sqlalchemy_declarative_extensions.schema import Schema, Schemas
 
+# isort: split
+from sqlalchemy_declarative_extensions.api import (
+    declarative_database,
+    declare_database,
+    register_sqlalchemy_events,
+)
+
 __all__ = [
     "declarative_database",
     "declare_database",
     "Grants",
+    "Role",
     "Row",
     "Rows",
-    "PGRole",
+    "dialects",
     "register_alembic_events",
+    "register_sqlalchemy_events",
     "Role",
     "Roles",
     "Schema",
