@@ -1,17 +1,21 @@
 from sqlalchemy_declarative_extensions.dialects import postgresql
 from sqlalchemy_declarative_extensions.dialects.query import (
+    check_schema_exists,
     get_default_grants,
     get_grants,
     get_objects,
     get_role_cls,
     get_roles,
+    get_schemas,
 )
 
 __all__ = [
     "postgresql",
+    "check_schema_exists",
     "get_default_grants",
     "get_grants",
     "get_roles",
     "get_objects",
     "get_role_cls",
+    "get_schemas",
 ]
