@@ -14,9 +14,24 @@ from sqlalchemy_declarative_extensions.dialects.postgresql.schema import (
     object_acl_query,
     objects_query,
     roles_query,
+    schema_exists_query,
+    schemas_query,
 )
 
 
+def get_schemas_postgresql(connection: Connection):
+    from sqlalchemy_declarative_extensions.schema.base import Schema
+
+    return {
+        Schema(schema) for schema, *_ in connection.execute(schemas_query).fetchall()
+    }
+
+
+def check_schema_exists_postgresql(connection: Connection, name: str) -> bool:
+    row = connection.execute(schema_exists_query, schema=name).scalar()
+    return not bool(row)
+
+
 def get_objects_postgresql(connection: Connection):
     return sorted(
         [
@@ -47,6 +62,7 @@ def get_default_grants_postgresql(
             for default_grant in default_grants:
                 if roles is None or default_grant.grant.target_role in roles:
                     result.append(default_grant)
+
     return result
 
 
@@ -74,6 +90,7 @@ def get_grants_postgresql(
             for grant in grants:
                 if roles is None or grant.grant.target_role in roles:
                     result.append(grant)
+
     return result
 
 
@@ -89,6 +106,6 @@ def get_roles_postgresql(connection: Connection, exclude=None):
 
 
 def qualify_name(schema, name):
-    if schema == "public":
+    if not schema or schema == "public":
         return name
     return f"{schema}.{name}"
