@@ -9,7 +9,7 @@ from sqlalchemy_declarative_extensions.role.compare import compare_roles
 
 def role_ddl(metadata: MetaData, connection: Connection, **_):
     roles: Optional[Roles] = metadata.info.get("roles")
-    if not roles:
+    if not roles:  # pragma: no cover
         return
 
     result = compare_roles(connection, roles)
